"""Peewee migrations: ::

    > Model = migrator.orm['name']

    > migrator.sql(sql)
    > migrator.python(func, *args, **kwargs)
    > migrator.create_model(Model)
    > migrator.remove_model(Model, cascade=True)
    > migrator.add_fields(Model, **fields)
    > migrator.change_fields(Model, **fields)
    > migrator.remove_fields(Model, *field_names, cascade=True)
    > migrator.rename_field(Model, old_field_name, new_field_name)
    > migrator.rename_table(Model, new_table_name)
    > migrator.add_index(Model, *col_names, unique=False)
    > migrator.drop_index(Model, *col_names)
    > migrator.add_not_null(Model, *field_names)
    > migrator.drop_not_null(Model, *field_names)
    > migrator.add_default(Model, field_name, default)

"""

import peewee as pw


class Country(pw.Model):
    code = pw.CharField(max_length=2, primary_key=True, null=False)
    name = pw.CharField(null=False)

    class Meta:
        db_table = "country"


def migrate(migrator, database, fake=False, **kwargs):
    """Write your migrations here."""

    IPList = migrator.orm["iplist"]
    Incident = migrator.orm["incident"]

    migrator.create_model(Country)

    migrator.add_fields(IPList, country=pw.ForeignKeyField(Country, null=True))
    migrator.add_fields(
        Incident, country=pw.ForeignKeyField(Country, null=True)
    )


def rollback(migrator, database, fake=False, **kwargs):
    """Write your rollback migrations here."""
    IPList = migrator.orm["iplist"]
    Incident = migrator.orm["incident"]

    migrator.remove_fields(IPList, "country")
    migrator.remove_fields(Incident, "country")
    migrator.remove_model(Country)
